import { l as logger, s as set } from "./index.b9537b42.js";
import Interpreter from "js-interpreter";
import "@builder.io/qwik";
import "@builder.io/qwik/jsx-runtime";
const processCode = (code) => {
  return code.split("\n").map((line) => {
    const trimmed = line.trim();
    if (line.includes("__awaiter"))
      return void 0;
    const isStateSetter = trimmed.startsWith("state.");
    if (!isStateSetter)
      return line;
    const [lhs, rhs] = trimmed.split("=");
    const setStr = lhs.replace("state.", "").trim();
    const setExpr = `setRootState('${setStr}', ${rhs.trim()})`;
    return `
  ${line}
  ${setExpr}
  `;
  }).filter(Boolean).join("\n");
};
const getJSONValName = (val) => val + "JSON";
const runInNonNode = ({ builder, context, event, rootState, localState, rootSetState, useCode }) => {
  const state = {
    ...rootState,
    ...localState
  };
  const properties = {
    state,
    Builder: builder,
    builder,
    context,
    event
  };
  const prependedCode = Object.keys(properties).map((key) => `var ${key} = JSON.parse(${getJSONValName(key)});`).join("\n");
  const cleanedCode = processCode(useCode);
  if (cleanedCode === "") {
    logger.warn("Skipping evaluation of empty code block.");
    return;
  }
  const transformed = `
function theFunction() {
  ${prependedCode}

  ${cleanedCode}
}
theFunction();
`;
  const setRootState = (prop, value) => {
    const newState = set(state, prop, value);
    rootSetState?.(newState);
  };
  const initFunc = function(interpreter, globalObject) {
    Object.keys(properties).forEach((key) => {
      const val = properties[key] || {};
      const jsonVal = JSON.stringify(val);
      interpreter.setProperty(globalObject, getJSONValName(key), jsonVal);
    });
    interpreter.setProperty(globalObject, "setRootState", interpreter.createNativeFunction(setRootState));
  };
  try {
    console.log("running code");
    const myInterpreter = new Interpreter(transformed, initFunc);
    myInterpreter.run();
    const output = myInterpreter.pseudoToNative(myInterpreter.value);
    return output;
  } catch (e) {
    logger.warn("Custom code error in non-node runtime. SDK can only execute ES5 JavaScript.", {
      e
    });
    return;
  }
};
export {
  runInNonNode
};
